@@ -2,10 +2,10 @@
 # Restricted SSH manager
 
 import subprocess
+from time import sleep
 
 from .tools import fix_path
 from .tools import askYesNo
-from .tools import squote
 from .tools import dquote
 
 class rssh:
@@ -14,9 +14,9 @@ class rssh:
 	"""
 	
 	def __init__(self, username, destination,
-		server = None, server_username = True,
+		server = None, server_username = None,
 		port = 8080, destination_port = 22,
-		autoconnect = True):
+		autoconnect = False):
 		"""
 		Initialize an rssh instance
 		:param username: Your username on destination machine
@@ -27,11 +27,6 @@ class rssh:
 		:param destination_port: The destination port
 		:param autoconnect: Connect on initialization?
 		"""
-		if server_username in (True, False):
-			if server_username:
-				server_username = username
-			else:
-				server_username = ""
 		self.username = username
 		self.destination = destination
 		self.server = server
@@ -96,12 +91,6 @@ class rssh:
 		else:
 			return "localhost"
 	
-	def isopen(self):
-		"""
-		Check if the gateway server connection is open
-		"""
-		return self.process is not None
-
 	def open(self):
 		"""
 		Open the connection to the gateway server
@@ -121,11 +110,35 @@ class rssh:
 		try:
 			print(f"connecting as {gateway}")
 			self.process = subprocess.Popen(cmd)
+			sleep(1) # allow time to connect
 			print(f"forwarding to {self.destination} on port {self.port}")
 		except Exception:
 			self.process = None
 			print("failed to open connection")
 	
+	def isopen(self):
+		"""
+		Check if the gateway server connection is open
+		"""
+		return self.process is not None
+	
+	def isbatch(self):
+		"""
+		Check if connection can be established without prompts
+		"""
+		dest = f"{self.username}@{self.hostname}"
+		if self.server is None:
+			cmd = ["ssh", dest]
+			cmd += ["-o", "BatchMode=yes"]
+		else:
+			self.open()
+			cmd = ["ssh", "-o", "NoHostAuthenticationForLocalhost=yes"]
+			cmd += ["-o", "BatchMode=yes"]
+			cmd += ["-p", str(self.port), dest]
+		cmd += ["true"]
+		proc = subprocess.run(cmd)
+		return proc.returncode == 0
+	
 	def ls(self, file = None, all_names = False, details = False):
 		"""
 		List files on the destination machine
@@ -137,6 +150,7 @@ class rssh:
 		if self.server is None:
 			cmd = ["ssh", host]
 		else:
+			self.open()
 			cmd = ["ssh", "-o", "NoHostAuthenticationForLocalhost=yes"]
 			cmd += ["-p", str(self.port), host]
 		cmd += ["ls"]
@@ -160,16 +174,17 @@ class rssh:
 		"""
 		truehost = f"{self.username}@{self.hostname}"
 		showhost = f"{self.username}@{self.destination}"
-		id_file = fix_path(id_file, must_exist=True)
+		id_file = fix_path(id_file, must_exist=True, escape_spaces=False)
 		print(f"key will be uploaded from: '{id_file}'")
 		print(f"key will be uploaded to: '{showhost}'")
 		if ask and not askYesNo():
 			return
 		print(f"copying key as {showhost}")
-		cmd = ["ssh-copy-id", "-i", dquote(id_file)]
+		cmd = ["ssh-copy-id", "-i", id_file]
 		if self.server is None:
 			cmd += [truehost]
 		else:
+			self.open()
 			cmd += ["-o", "NoHostAuthenticationForLocalhost=yes"]
 			cmd += ["-p", str(self.port)]
 			cmd += [truehost]
@@ -186,7 +201,7 @@ class rssh:
 		truesrc = f"{self.username}@{self.hostname}:{dquote(src)}"
 		showsrc = f"{self.username}@{self.destination}:{dquote(src)}"
 		has_trailing_slash = dest[-1] == "/"
-		dest = fix_path(dest, must_exist=False)
+		dest = fix_path(dest, must_exist=False, escape_spaces=False)
 		if dest[-1] != "/" and has_trailing_slash:
 			dest += "/"
 		print(f"data will be downloaded from: '{showsrc}'")
@@ -195,11 +210,12 @@ class rssh:
 			return
 		print(f"downloading data as {self.username}@{self.destination}")
 		if self.server is None:
-			cmd = ["rsync", "-aP", truesrc, dquote(dest)]
+			cmd = ["rsync", "-aP", truesrc, dest]
 		else:
+			self.open()
 			rsh = ["ssh", "-o", "NoHostAuthenticationForLocalhost=yes"]
 			rsh = " ".join(rsh + ["-p", str(self.port)])
-			cmd = ["rsync", "-aP", "--rsh", rsh, truesrc, dquote(dest)]
+			cmd = ["rsync", "-aP", "--rsh", rsh, truesrc, dest]
 		if dry_run:
 			cmd += ["--dry-run"]
 		return subprocess.run(cmd)
@@ -215,7 +231,7 @@ class rssh:
 		truedest = f"{self.username}@{self.hostname}:{dquote(dest)}"
 		showdest = f"{self.username}@{self.destination}:{dquote(dest)}"
 		has_trailing_slash = src[-1] == "/"
-		src = fix_path(src, must_exist=True)
+		src = fix_path(src, must_exist=True, escape_spaces=False)
 		if src[-1] != "/" and has_trailing_slash:
 			src += "/"
 		print(f"data will be uploaded from: '{src}'")
@@ -224,11 +240,12 @@ class rssh:
 			return
 		print(f"uploading data as {self.username}@{self.destination}")
 		if self.server is None:
-			cmd = ["rsync", "-aP", dquote(src), truedest]
+			cmd = ["rsync", "-aP", src, truedest]
 		else:
+			self.open()
 			rsh = ["ssh", "-o", "NoHostAuthenticationForLocalhost=yes"]
 			rsh = " ".join(rsh + ["-p", str(self.port)])
-			cmd = ["rsync", "-aP", "--rsh", rsh, dquote(src), truedest]
+			cmd = ["rsync", "-aP", "--rsh", rsh, src, truedest]
 		if dry_run:
 			cmd += ["--dry-run"]
 		return subprocess.run(cmd)
@@ -242,6 +259,7 @@ class rssh:
 		if self.server is None:
 			cmd = ["ssh", dest]
 		else:
+			self.open()
 			cmd = ["ssh", "-o", "NoHostAuthenticationForLocalhost=yes"]
 			cmd += ["-p", str(self.port), dest]
 		return subprocess.run(cmd)
